@@ -2,7 +2,7 @@ from time import sleep
 
 from testutil import AbstractOperatorTest, get_cr, get_k8s_task_object
 
-from fastflow.helpers import create_workflow_crd_object
+from fastflow.kubernetes import create_workflow_crd_object
 from fastflow.models import WORKFLOWSTATUS, WorkflowCRD
 
 global_inputs = {
